#!/usr/bin/python3

import sys, os
from PIL import Image
import numpy as np

HUE = {}
HUE["Aqua"] = 201
HUE["Blue"] = 226
HUE["Brown"] = 27
HUE["Grey"] = 0
HUE["Orange"] = 30
HUE["Pink"] = 327
HUE["Purple"] = 260
HUE["Red"] = 2
HUE["Sand"] = 42
HUE["Teal"] = 168

def rgb_to_hsv(rgb):
    # Translated from source of colorsys.rgb_to_hsv
    # r,g,b should be a numpy arrays with values between 0 and 255
    # rgb_to_hsv returns an array of floats between 0.0 and 1.0.
    rgb = rgb.astype('float')
    hsv = np.zeros_like(rgb)
    # in case an RGBA array was passed, just copy the A channel
    hsv[..., 3:] = rgb[..., 3:]
    r, g, b = rgb[..., 0], rgb[..., 1], rgb[..., 2]
    maxc = np.max(rgb[..., :3], axis=-1)
    minc = np.min(rgb[..., :3], axis=-1)
    hsv[..., 2] = maxc
    mask = maxc != minc
    hsv[mask, 1] = (maxc - minc)[mask] / maxc[mask]
    rc = np.zeros_like(r)
    gc = np.zeros_like(g)
    bc = np.zeros_like(b)
    rc[mask] = (maxc - r)[mask] / (maxc - minc)[mask]
    gc[mask] = (maxc - g)[mask] / (maxc - minc)[mask]
    bc[mask] = (maxc - b)[mask] / (maxc - minc)[mask]
    hsv[..., 0] = np.select(
        [r == maxc, g == maxc], [bc - gc, 2.0 + rc - bc], default=4.0 + gc - rc)
    hsv[..., 0] = (hsv[..., 0] / 6.0) % 1.0
    return hsv

def hsv_to_rgb(hsv):
    # Translated from source of colorsys.hsv_to_rgb
    # h,s should be a numpy arrays with values between 0.0 and 1.0
    # v should be a numpy array with values between 0.0 and 255.0
    # hsv_to_rgb returns an array of uints between 0 and 255.
    rgb = np.empty_like(hsv)
    rgb[..., 3:] = hsv[..., 3:]
    h, s, v = hsv[..., 0], hsv[..., 1], hsv[..., 2]
    i = (h * 6.0).astype('uint8')
    f = (h * 6.0) - i
    p = v * (1.0 - s)
    q = v * (1.0 - s * f)
    t = v * (1.0 - s * (1.0 - f))
    i = i % 6
    conditions = [s == 0.0, i == 1, i == 2, i == 3, i == 4, i == 5]
    rgb[..., 0] = np.select(conditions, [v, q, p, p, t, v], default=v)
    rgb[..., 1] = np.select(conditions, [v, v, v, q, p, p], default=t)
    rgb[..., 2] = np.select(conditions, [v, p, t, v, v, q], default=p)
    return rgb.astype('uint8')


def shift_hue(arr,hout):
    hsv=rgb_to_hsv(arr)
    hsv[...,0]=hout
    rgb=hsv_to_rgb(hsv)
    return rgb


filename = sys.argv[1]
if not os.path.exists(filename):
    print("File not found %s" % filename)
    sys.exit(1)

color = sys.argv[2]
if color not in HUE.keys():
    print("Unknown color: %s!" % color)
    sys.exit(1)

hue = HUE[color]

img = Image.open(filename).convert('RGBA')
arr = np.array(img)

if __name__=='__main__':
    hue_value = hue/360.0
    new_img = Image.fromarray(shift_hue(arr,hue_value), 'RGBA')
    new_img.save(filename)



#!/usr/bin/python3

# Mint-X
X_HEX_ACCENTS = ["#9ab87c", "#accd8a"]

x_hex_colors = {}
x_hex_colors["Aqua"] = "#6cabcd"
x_hex_colors["Blue"] = "#5b73c4"
x_hex_colors["Brown"] = "#aa876a"
x_hex_colors["Grey"] = "#9d9d9d"
x_hex_colors["Orange"] = "#db9d61"
x_hex_colors["Pink"] = "#c76199"
x_hex_colors["Purple"] = "#8c6ec9"
x_hex_colors["Red"] = "#c15b58"
x_hex_colors["Sand"] = "#c8ac69"
x_hex_colors["Teal"] = "#5aaa9a"

X_RGB_ACCENTS = ["172, 205, 138", "#accd8a"]

x_rgb_colors = {}
x_rgb_colors["Aqua"] = "108, 171, 205"
x_rgb_colors["Blue"] = "91, 115, 196"
x_rgb_colors["Brown"] = "170, 135, 106"
x_rgb_colors["Grey"] = "157,157,157"
x_rgb_colors["Orange"] = "219, 157, 97"
x_rgb_colors["Pink"] = "199, 97, 153"
x_rgb_colors["Purple"] = "140, 110, 201"
x_rgb_colors["Red"] = "193, 91, 88"
x_rgb_colors["Sand"] = "200, 172, 105"
x_rgb_colors["Teal"] = "90, 170, 154"


# Mint-Y
Y_HEX_ACCENT1 = ["#92b372"]  # BASE
Y_HEX_ACCENT2 = ["#8fa876"]  # DARK
Y_HEX_ACCENT3 = ["#afca95"]  # PRELIGHT/HOVER
Y_HEX_ACCENT4 = ["#779559"]  # PRESSED

y_hex_colors1 = {}
y_hex_colors2 = {}
y_hex_colors3 = {}
y_hex_colors4 = {}

y_hex_colors1["Aqua"] = "#6cabcd"
y_hex_colors2["Aqua"] = "#6aa0bd"
y_hex_colors3["Aqua"] = "#82b3ce"
y_hex_colors4["Aqua"] = "#52819a"

y_hex_colors1["Blue"] = "#5b73c4"
y_hex_colors2["Blue"] = "#596eb5"
y_hex_colors3["Blue"] = "#6e82c6"
y_hex_colors4["Blue"] = "#4b5a8d"

y_hex_colors1["Brown"] = "#aa876a"
y_hex_colors2["Brown"] = "#9c7e65"
y_hex_colors3["Brown"] = "#ad9078"
y_hex_colors4["Brown"] = "#796555"

y_hex_colors1["Grey"] = "#9d9d9d"
y_hex_colors2["Grey"] = "#8f8f8f"
y_hex_colors3["Grey"] = "#a3a3a3"
y_hex_colors4["Grey"] = "#727272"

y_hex_colors1["Orange"] = "#db9d61"
y_hex_colors2["Orange"] = "#cc9560"
y_hex_colors3["Orange"] = "#dcaa7a"
y_hex_colors4["Orange"] = "#a97747"

y_hex_colors1["Pink"] = "#c76199"
y_hex_colors2["Pink"] = "#b85f90"
y_hex_colors3["Pink"] = "#c975a3"
y_hex_colors4["Pink"] = "#924d73"

y_hex_colors1["Purple"] = "#8c6ec9"
y_hex_colors2["Purple"] = "#866cba"
y_hex_colors3["Purple"] = "#9b84cb"
y_hex_colors4["Purple"] = "#6a5497"

y_hex_colors1["Red"] = "#c15b58"
y_hex_colors2["Red"] = "#b35a57"
y_hex_colors3["Red"] = "#d1716f"
y_hex_colors4["Red"] = "#9a4a47"

y_hex_colors1["Sand"] = "#c8ac69"
y_hex_colors2["Sand"] = "#b89f65"
y_hex_colors3["Sand"] = "#c9b27c"
y_hex_colors4["Sand"] = "#947f51"

y_hex_colors1["Teal"] = "#5aaa9a"
y_hex_colors2["Teal"] = "#579c8e"
y_hex_colors3["Teal"] = "#6dbbab"
y_hex_colors4["Teal"] = "#4e8378"
